@@ -64,13 +64,13 @@ def sync_stream(config, state, stream):
             rows_saved += full_table.sync(config, state, stream)
 
         if log_based.has_stream_aged_out(state, table_name):
-            LOGGER.info("Clearing state because stream has aged out : %s",singer.get_bookmark(state, table_name, 'initial_full_table_complete'))
+            LOGGER.info("Clearing state because stream has aged out...")
             state.get('bookmarks', {}).pop(table_name)
             # as full table already done
-            state = singer.write_bookmark(state,
-                                    table_name,
-                                    'initial_full_table_complete',
-                                    True)
+            # state = singer.write_bookmark(state,
+            #                         table_name,
+            #                         'initial_full_table_complete',
+            #                         True)
 
         rows_saved += log_based.sync(config, state, stream)
     else:
